@@ -1,11 +1,9 @@
-from statsmodels.compat.python import iteritems
-
 import functools
 import inspect
 from textwrap import dedent
 
 
-class ResultsWrapper(object):
+class ResultsWrapper:
     """
     Class which wraps a statsmodels estimation Results class and steps in to
     reattach metadata to results (if available)
@@ -119,13 +117,13 @@ def make_wrapper(func, how):
     formatted = str(sig)
 
     doc = dedent(wrapper.__doc__) if wrapper.__doc__ else ''
-    wrapper.__doc__ = "\n%s%s\n%s" % (func.__name__, formatted, doc)
+    wrapper.__doc__ = "\n{}{}\n{}".format(func.__name__, formatted, doc)
 
     return wrapper
 
 
 def populate_wrapper(klass, wrapping):
-    for meth, how in iteritems(klass._wrap_methods):
+    for meth, how in klass._wrap_methods.items():
         if not hasattr(wrapping, meth):
             continue
 
