@@ -96,7 +96,7 @@ def contrast_labels(contrasts, names, reverse=False):
         sl = slice(None, None, -1)
     else:
         sl = slice(None)
-    labels = [''.join(['%s%s' % (signstr(c, noplus=True),v)
+    labels = [''.join(['{}{}'.format(signstr(c, noplus=True),v)
                           for c,v in zip(row, names)[sl] if c != 0])
                              for row in contrasts]
     return labels
@@ -126,7 +126,7 @@ def contrast_product(names1, names2, intgroup1=None, intgroup2=None, pairs=False
 
     n1 = len(names1)
     n2 = len(names2)
-    names_prod = ['%s_%s' % (i,j) for i in names1 for j in names2]
+    names_prod = ['{}_{}'.format(i,j) for i in names1 for j in names2]
     ee1 = np.zeros((1,n1))
     ee1[0,0] = 1
     if not pairs:
@@ -136,7 +136,7 @@ def contrast_product(names1, names2, intgroup1=None, intgroup2=None, pairs=False
 
     contrast_prod = np.kron(dd[1:], np.eye(n2))
     names_contrast_prod0 = contrast_labels(contrast_prod, names_prod, reverse=True)
-    names_contrast_prod = [''.join(['%s%s' % (signstr(c, noplus=True),v)
+    names_contrast_prod = [''.join(['{}{}'.format(signstr(c, noplus=True),v)
                               for c,v in zip(row, names_prod)[::-1] if c != 0])
                                  for row in contrast_prod]
 
@@ -149,7 +149,7 @@ def contrast_product(names1, names2, intgroup1=None, intgroup2=None, pairs=False
         dd2 = np.r_[ee2, -contrast_allpairs(n2)]
 
     contrast_prod2 = np.kron(np.eye(n1), dd2[1:])
-    names_contrast_prod2 = [''.join(['%s%s' % (signstr(c, noplus=True),v)
+    names_contrast_prod2 = [''.join(['{}{}'.format(signstr(c, noplus=True),v)
                               for c,v in zip(row, names_prod)[::-1] if c != 0])
                                  for row in contrast_prod2]
 
@@ -682,12 +682,12 @@ if __name__ == '__main__':
     print(np.dot(tr_of, params_f_f) - params_f_df)
 
     transf_f_df = DummyTransform(dd_full, dd_dropf)
-    print(np.max(np.abs((dd_full - transf_f_df.inv_dot_right(dd_dropf)))))
-    print(np.max(np.abs((dd_dropf - transf_f_df.dot_right(dd_full)))))
-    print(np.max(np.abs((params_df_df
-                         - transf_f_df.inv_dot_left(params_df_f)))))
-    np.max(np.abs((params_f_df
-                         - transf_f_df.inv_dot_left(params_f_f))))
+    print(np.max(np.abs(dd_full - transf_f_df.inv_dot_right(dd_dropf))))
+    print(np.max(np.abs(dd_dropf - transf_f_df.dot_right(dd_full))))
+    print(np.max(np.abs(params_df_df
+                         - transf_f_df.inv_dot_left(params_df_f))))
+    np.max(np.abs(params_f_df
+                         - transf_f_df.inv_dot_left(params_f_f)))
 
     prodlab, C1, C1lab, C2, C2lab,_ = contrast_product(v1name, v2name)
 
@@ -708,7 +708,7 @@ if __name__ == '__main__':
     R_noint = np.hstack((np.zeros((2,4)), np.eye(2)))
     inter_direct = resols_full_dropf.tvalues[-2:]
     inter_transf = resols_full_full.t_test(transf_f_df.inv_dot_right(R_noint)).tvalue
-    print(np.max(np.abs((inter_direct - inter_transf))))
+    print(np.max(np.abs(inter_direct - inter_transf)))
 
     #now with class version
     tw = TwoWay(ydata_dropf, x1, x2)
