@@ -1,12 +1,12 @@
 """
 Substantially copied from NumpyDoc 1.0pre.
 """
+from collections import namedtuple
+from collections.abc import Mapping
 import copy
 import inspect
 import re
 import textwrap
-from collections import namedtuple
-from collections.abc import Mapping
 
 from statsmodels.tools.sm_exceptions import ParseError
 
@@ -25,7 +25,7 @@ def strip_blank_lines(line):
     return line
 
 
-class Reader(object):
+class Reader:
     """
     A line-based string reader.
     """
@@ -40,7 +40,7 @@ class Reader(object):
         if isinstance(data, list):
             self._str = data
         else:
-            self._str = data.split('\n')  # store string as list of lines
+            self._str = data.split("\n")  # store string as list of lines
 
         self.reset()
 
@@ -56,10 +56,10 @@ class Reader(object):
             self._line_num += 1
             return out
         else:
-            return ''
+            return ""
 
     def seek_next_non_empty_line(self):
-        for line in self[self._line_num:]:
+        for line in self[self._line_num :]:
             if line.strip():
                 break
             else:
@@ -72,10 +72,10 @@ class Reader(object):
         start = self._line_num
         for line in self[start:]:
             if condition_func(line):
-                return self[start:self._line_num]
+                return self[start : self._line_num]
             self._line_num += 1
             if self.eof():
-                return self[start:self._line_num + 1]
+                return self[start : self._line_num + 1]
         return []
 
     def read_to_next_empty_line(self):
@@ -88,7 +88,7 @@ class Reader(object):
 
     def read_to_next_unindented_line(self):
         def is_unindented(line):
-            return (line.strip() and (len(line.lstrip()) == len(line)))
+            return line.strip() and (len(line.lstrip()) == len(line))
 
         return self.read_to_condition(is_unindented)
 
@@ -96,13 +96,13 @@ class Reader(object):
         if self._line_num + n < len(self._str):
             return self[self._line_num + n]
         else:
-            return ''
+            return ""
 
     def is_empty(self):
-        return not ''.join(self._str).strip()
+        return not "".join(self._str).strip()
 
 
-Parameter = namedtuple('Parameter', ['name', 'type', 'desc'])
+Parameter = namedtuple("Parameter", ["name", "type", "desc"])
 
 
 class NumpyDocString(Mapping):
@@ -112,29 +112,29 @@ class NumpyDocString(Mapping):
     """
 
     sections = {
-        'Signature': '',
-        'Summary': [''],
-        'Extended Summary': [],
-        'Parameters': [],
-        'Returns': [],
-        'Yields': [],
-        'Receives': [],
-        'Raises': [],
-        'Warns': [],
-        'Other Parameters': [],
-        'Attributes': [],
-        'Methods': [],
-        'See Also': [],
-        'Notes': [],
-        'Warnings': [],
-        'References': '',
-        'Examples': '',
-        'index': {}
+        "Signature": "",
+        "Summary": [""],
+        "Extended Summary": [],
+        "Parameters": [],
+        "Returns": [],
+        "Yields": [],
+        "Receives": [],
+        "Raises": [],
+        "Warns": [],
+        "Other Parameters": [],
+        "Attributes": [],
+        "Methods": [],
+        "See Also": [],
+        "Notes": [],
+        "Warnings": [],
+        "References": "",
+        "Examples": "",
+        "index": {},
     }
 
     def __init__(self, docstring):
         orig_docstring = docstring
-        docstring = textwrap.dedent(docstring).split('\n')
+        docstring = textwrap.dedent(docstring).split("\n")
 
         self._doc = Reader(docstring)
         self._parsed_data = copy.deepcopy(self.sections)
@@ -168,11 +168,11 @@ class NumpyDocString(Mapping):
 
         l1 = self._doc.peek().strip()  # e.g. Parameters
 
-        if l1.startswith('.. index::'):
+        if l1.startswith(".. index::"):
             return True
 
         l2 = self._doc.peek(1).strip()  # ---------- or ==========
-        return l2.startswith('-' * len(l1)) or l2.startswith('=' * len(l1))
+        return l2.startswith("-" * len(l1)) or l2.startswith("=" * len(l1))
 
     def _strip(self, doc):
         i = 0
@@ -185,14 +185,14 @@ class NumpyDocString(Mapping):
             if line.strip():
                 break
 
-        return doc[i:len(doc) - j]
+        return doc[i : len(doc) - j]
 
     def _read_to_next_section(self):
         section = self._doc.read_to_next_empty_line()
 
         while not self._is_at_section() and not self._doc.eof():
             if not self._doc.peek(-1).strip():  # previous line was empty
-                section += ['']
+                section += [""]
 
             section += self._doc.read_to_next_empty_line()
 
@@ -203,7 +203,7 @@ class NumpyDocString(Mapping):
             data = self._read_to_next_section()
             name = data[0].strip()
 
-            if name.startswith('..'):  # index section
+            if name.startswith(".."):  # index section
                 yield name, data[1:]
             elif len(data) < 2:
                 yield StopIteration
@@ -215,13 +215,13 @@ class NumpyDocString(Mapping):
         params = []
         while not r.eof():
             header = r.read().strip()
-            if ' : ' in header:
-                arg_name, arg_type = header.split(' : ')[:2]
+            if " : " in header:
+                arg_name, arg_type = header.split(" : ")[:2]
             else:
                 if single_element_is_type:
-                    arg_name, arg_type = '', header
+                    arg_name, arg_type = "", header
                 else:
-                    arg_name, arg_type = header, ''
+                    arg_name, arg_type = header, ""
 
             desc = r.read_to_next_unindented_line()
             desc = dedent_lines(desc)
@@ -251,22 +251,26 @@ class NumpyDocString(Mapping):
     _funcbacktick = r"`(?P<name>(?:~\w+\.)?[a-zA-Z0-9_\.-]+)`"
     _funcplain = r"(?P<name2>[a-zA-Z0-9_\.-]+)"
     _funcname = r"(" + _role + _funcbacktick + r"|" + _funcplain + r")"
-    _funcnamenext = _funcname.replace('role', 'rolenext')
-    _funcnamenext = _funcnamenext.replace('name', 'namenext')
+    _funcnamenext = _funcname.replace("role", "rolenext")
+    _funcnamenext = _funcnamenext.replace("name", "namenext")
     _description = r"(?P<description>\s*:(\s+(?P<desc>\S+.*))?)?\s*$"
     _func_rgx = re.compile(r"^\s*" + _funcname + r"\s*")
     _line_rgx = re.compile(
-        r"^\s*" +
-        r"(?P<allfuncs>" +  # group for all function names
-        _funcname +
-        r"(?P<morefuncs>([,]\s+" + _funcnamenext + r")*)" +
-        r")" +  # end of "allfuncs"
+        r"^\s*"
+        + r"(?P<allfuncs>"
+        + _funcname  # group for all function names
+        + r"(?P<morefuncs>([,]\s+"
+        + _funcnamenext
+        + r")*)"
+        + r")"
+        +  # end of "allfuncs"
         # Some function lists have a trailing comma (or period)
-        r"(?P<trailing>[,\.])?" +
-        _description)
+        r"(?P<trailing>[,\.])?"
+        + _description
+    )
 
     # Empty <DESC> elements are replaced with '..'
-    empty_description = '..'
+    empty_description = ".."
 
     def _parse_see_also(self, content):
         """
@@ -283,8 +287,8 @@ class NumpyDocString(Mapping):
             m = self._func_rgx.match(text)
             if not m:
                 raise ParseError(f"{text} is not a item name")
-            role = m.group('role')
-            name = m.group('name') if role else m.group('name2')
+            role = m.group("role")
+            name = m.group("name") if role else m.group("name2")
             return name, role, m.end()
 
         rest = []
@@ -295,24 +299,25 @@ class NumpyDocString(Mapping):
             line_match = self._line_rgx.match(line)
             description = None
             if line_match:
-                description = line_match.group('desc')
-                if line_match.group('trailing') and description:
+                description = line_match.group("desc")
+                if line_match.group("trailing") and description:
                     self._error_location(
-                        'Unexpected comma or period after function list at '
-                        'index %d of line '
-                        '"%s"' % (line_match.end('trailing'), line))
-            if not description and line.startswith(' '):
+                        "Unexpected comma or period after function list at "
+                        "index %d of line "
+                        '"%s"' % (line_match.end("trailing"), line)
+                    )
+            if not description and line.startswith(" "):
                 rest.append(line.strip())
             elif line_match:
                 funcs = []
-                text = line_match.group('allfuncs')
+                text = line_match.group("allfuncs")
                 while True:
                     if not text.strip():
                         break
                     name, role, match_end = parse_item_name(text)
                     funcs.append((name, role))
                     text = text[match_end:].strip()
-                    if text and text[0] == ',':
+                    if text and text[0] == ",":
                         text = text[1:].strip()
                 rest = list(filter(None, [description]))
                 items.append((funcs, rest))
@@ -330,13 +335,13 @@ class NumpyDocString(Mapping):
             return [s.strip() for s in lst]
 
         out = {}
-        section = section.split('::')
+        section = section.split("::")
         if len(section) > 1:
-            out['default'] = strip_each_in(section[1].split(','))[0]
+            out["default"] = strip_each_in(section[1].split(","))[0]
         for line in content:
-            line = line.split(':')
+            line = line.split(":")
             if len(line) > 2:
-                out[line[1]] = strip_each_in(line[2].split(','))
+                out[line[1]] = strip_each_in(line[2].split(","))
         return out
 
     def _parse_summary(self):
@@ -348,96 +353,108 @@ class NumpyDocString(Mapping):
         while True:
             summary = self._doc.read_to_next_empty_line()
             summary_str = " ".join([s.strip() for s in summary]).strip()
-            compiled = re.compile(r'^([\w., ]+=)?\s*[\w\.]+\(.*\)$')
+            compiled = re.compile(r"^([\w., ]+=)?\s*[\w\.]+\(.*\)$")
             if compiled.match(summary_str):
-                self['Signature'] = summary_str
+                self["Signature"] = summary_str
                 if not self._is_at_section():
                     continue
             break
 
         if summary is not None:
-            self['Summary'] = summary
+            self["Summary"] = summary
 
         if not self._is_at_section():
-            self['Extended Summary'] = self._read_to_next_section()
+            self["Extended Summary"] = self._read_to_next_section()
 
     def _parse(self):
         self._doc.reset()
         self._parse_summary()
 
         sections = list(self._read_sections())
-        section_names = set([section for section, content in sections])
+        section_names = {section for section, content in sections}
 
-        has_returns = 'Returns' in section_names
-        has_yields = 'Yields' in section_names
+        has_returns = "Returns" in section_names
+        has_yields = "Yields" in section_names
         # We could do more tests, but we are not. Arbitrarily.
         if has_returns and has_yields:
-            msg = 'Docstring contains both a Returns and Yields section.'
+            msg = "Docstring contains both a Returns and Yields section."
             raise ValueError(msg)
-        if not has_yields and 'Receives' in section_names:
-            msg = 'Docstring contains a Receives section but not Yields.'
+        if not has_yields and "Receives" in section_names:
+            msg = "Docstring contains a Receives section but not Yields."
             raise ValueError(msg)
 
         for (section, content) in sections:
-            if not section.startswith('..'):
-                section = (s.capitalize() for s in section.split(' '))
-                section = ' '.join(section)
+            if not section.startswith(".."):
+                section = (s.capitalize() for s in section.split(" "))
+                section = " ".join(section)
                 if self.get(section):
-                    self._error_location("The section %s appears twice"
-                                         % section)
+                    self._error_location(
+                        "The section %s appears twice" % section
+                    )
 
-            if section in ('Parameters', 'Other Parameters', 'Attributes',
-                           'Methods'):
+            if section in (
+                "Parameters",
+                "Other Parameters",
+                "Attributes",
+                "Methods",
+            ):
                 self[section] = self._parse_param_list(content)
             elif section in (
-                    'Returns', 'Yields', 'Raises', 'Warns', 'Receives'):
+                "Returns",
+                "Yields",
+                "Raises",
+                "Warns",
+                "Receives",
+            ):
                 self[section] = self._parse_param_list(
-                    content, single_element_is_type=True)
-            elif section.startswith('.. index::'):
-                self['index'] = self._parse_index(section, content)
-            elif section == 'See Also':
-                self['See Also'] = self._parse_see_also(content)
+                    content, single_element_is_type=True
+                )
+            elif section.startswith(".. index::"):
+                self["index"] = self._parse_index(section, content)
+            elif section == "See Also":
+                self["See Also"] = self._parse_see_also(content)
             else:
                 self[section] = content
 
     def _error_location(self, msg):
-        if hasattr(self, '_obj'):
+        if hasattr(self, "_obj"):
             # we know where the docs came from:
             try:
                 filename = inspect.getsourcefile(self._obj)
             except TypeError:
                 filename = None
-            msg = msg + (" in the docstring of %s in %s."
-                         % (self._obj, filename))
+            msg = msg + (
+                " in the docstring of {} in {}.".format(self._obj, filename)
+            )
 
         raise ValueError(msg)
 
     # string conversion routines
 
-    def _str_header(self, name, symbol='-'):
+    def _str_header(self, name, symbol="-"):
         return [name, len(name) * symbol]
 
     def _str_indent(self, doc, indent=4):
         out = []
         for line in doc:
-            out += [' ' * indent + line]
+            out += [" " * indent + line]
         return out
 
     def _str_signature(self):
-        if self['Signature']:
-            return [self['Signature'].replace('*', r'\*')] + ['']
+        if self["Signature"]:
+            return [self["Signature"].replace("*", r"\*")] + [""]
         else:
-            return ['']
+            return [""]
 
     def _str_summary(self):
-        if self['Summary']:
-            return self['Summary'] + ['']
+        if self["Summary"]:
+            return self["Summary"] + [""]
         else:
             return []
 
     def _str_extended_summary(self):
-        if self['Extended Summary']:
-            return self['Extended Summary'] + ['']
+        if self["Extended Summary"]:
+            return self["Extended Summary"] + [""]
         else:
             return []
 
@@ -451,10 +468,10 @@ class NumpyDocString(Mapping):
                     parts.append(param.name)
                 if param.type:
                     parts.append(param.type)
-                out += [' : '.join(parts)]
-                if param.desc and ''.join(param.desc).strip():
+                out += [" : ".join(parts)]
+                if param.desc and "".join(param.desc).strip():
                     out += self._str_indent(param.desc)
-            out += ['']
+            out += [""]
         return out
 
     def _str_section(self, name):
@@ -462,76 +479,83 @@ class NumpyDocString(Mapping):
         if self[name]:
             out += self._str_header(name)
             out += self[name]
-            out += ['']
+            out += [""]
         return out
 
     def _str_see_also(self, func_role):
-        if not self['See Also']:
+        if not self["See Also"]:
             return []
         out = []
         out += self._str_header("See Also")
         last_had_desc = True
-        for funcs, desc in self['See Also']:
+        for funcs, desc in self["See Also"]:
             assert isinstance(funcs, list)
             links = []
             for func, role in funcs:
                 if role:
-                    link = ':%s:`%s`' % (role, func)
+                    link = ":{}:`{}`".format(role, func)
                 elif func_role:
-                    link = ':%s:`%s`' % (func_role, func)
+                    link = ":{}:`{}`".format(func_role, func)
                 else:
                     link = "%s" % func
                 links.append(link)
-            link = ', '.join(links)
+            link = ", ".join(links)
             out += [link]
             if desc:
-                out += self._str_indent([' '.join(desc)])
+                out += self._str_indent([" ".join(desc)])
                 last_had_desc = True
             else:
                 last_had_desc = False
                 out += self._str_indent([self.empty_description])
 
         if last_had_desc:
-            out += ['']
+            out += [""]
         return out
 
     def _str_index(self):
-        idx = self['index']
+        idx = self["index"]
         out = []
         output_index = False
-        default_index = idx.get('default', '')
+        default_index = idx.get("default", "")
         if default_index:
             output_index = True
-        out += ['.. index:: %s' % default_index]
+        out += [".. index:: %s" % default_index]
         for section, references in idx.items():
-            if section == 'default':
+            if section == "default":
                 continue
             output_index = True
-            out += ['   :%s: %s' % (section, ', '.join(references))]
+            out += ["   :{}: {}".format(section, ", ".join(references))]
         if output_index:
             return out
         else:
-            return ''
+            return ""
 
-    def __str__(self, func_role=''):
+    def __str__(self, func_role=""):
         out = []
         out += self._str_signature()
         out += self._str_summary()
         out += self._str_extended_summary()
-        for param_list in ('Parameters', 'Returns', 'Yields', 'Receives',
-                           'Other Parameters', 'Raises', 'Warns'):
+        for param_list in (
+            "Parameters",
+            "Returns",
+            "Yields",
+            "Receives",
+            "Other Parameters",
+            "Raises",
+            "Warns",
+        ):
             out += self._str_param_list(param_list)
-        out += self._str_section('Warnings')
+        out += self._str_section("Warnings")
         out += self._str_see_also(func_role)
-        for s in ('Notes', 'References', 'Examples'):
+        for s in ("Notes", "References", "Examples"):
             out += self._str_section(s)
-        for param_list in ('Attributes', 'Methods'):
+        for param_list in ("Attributes", "Methods"):
             out += self._str_param_list(param_list)
         out += self._str_index()
-        return '\n'.join(out)
+        return "\n".join(out)
 
 
-class Docstring(object):
+class Docstring:
     """
     Docstring modification.
 
@@ -560,11 +584,14 @@ class Docstring(object):
             return
         if isinstance(parameters, str):
             parameters = [parameters]
-        repl = [param for param in self._ds['Parameters']
-                if param.name not in parameters]
-        if len(repl) + len(parameters) != len(self._ds['Parameters']):
-            raise ValueError('One or more parameters were not found.')
-        self._ds['Parameters'] = repl
+        repl = [
+            param
+            for param in self._ds["Parameters"]
+            if param.name not in parameters
+        ]
+        if len(repl) + len(parameters) != len(self._ds["Parameters"]):
+            raise ValueError("One or more parameters were not found.")
+        self._ds["Parameters"] = repl
 
     def insert_parameters(self, after, parameters):
         """
@@ -582,18 +609,18 @@ class Docstring(object):
         if isinstance(parameters, Parameter):
             parameters = [parameters]
         if after is None:
-            self._ds['Parameters'] = parameters + self._ds['Parameters']
+            self._ds["Parameters"] = parameters + self._ds["Parameters"]
         else:
             loc = -1
-            for i, param in enumerate(self._ds['Parameters']):
+            for i, param in enumerate(self._ds["Parameters"]):
                 if param.name == after:
-                    loc = i+1
+                    loc = i + 1
                     break
             if loc < 0:
                 raise ValueError()
-            params = self._ds['Parameters'][:loc] + parameters
-            params += self._ds['Parameters'][loc:]
-            self._ds['Parameters'] = params
+            params = self._ds["Parameters"][:loc] + parameters
+            params += self._ds["Parameters"][loc:]
+            self._ds["Parameters"] = params
 
     def replace_block(self, block_name, block):
         """
@@ -608,12 +635,14 @@ class Docstring(object):
         if self._docstring is None:
             # Protection against -oo execution
             return
-        block_name = ' '.join(map(str.capitalize, block_name.split(' ')))
+        block_name = " ".join(map(str.capitalize, block_name.split(" ")))
         if block_name not in self._ds:
-            raise ValueError('{0} is not a block in the '
-                             'docstring'.format(block_name))
-        if not isinstance(block, list) and \
-                isinstance(self._ds[block_name], list):
+            raise ValueError(
+                "{} is not a block in the " "docstring".format(block_name)
+            )
+        if not isinstance(block, list) and isinstance(
+            self._ds[block_name], list
+        ):
             block = [block]
         self._ds[block_name] = block
 
@@ -623,23 +652,25 @@ class Docstring(object):
             return
         if isinstance(parameters, str):
             parameters = [parameters]
-        ds_params = {param.name: param for param in self._ds['Parameters']}
+        ds_params = {param.name: param for param in self._ds["Parameters"]}
         missing = set(parameters).difference(ds_params.keys())
         if missing:
-            raise ValueError('{0} were not found in the '
-                             'docstring'.format(','.join(missing)))
+            raise ValueError(
+                "{} were not found in the "
+                "docstring".format(",".join(missing))
+            )
         final = [ds_params[param] for param in parameters]
         ds = copy.deepcopy(self._ds)
         for key in ds:
-            if key != 'Parameters':
-                ds[key] = [] if key != 'index' else {}
+            if key != "Parameters":
+                ds[key] = [] if key != "index" else {}
             else:
                 ds[key] = final
         out = str(ds).strip()
         if indent:
-            out = textwrap.indent(out, ' ' * indent)
+            out = textwrap.indent(out, " " * indent)
 
-        out = '\n'.join(out.split('\n')[2:])
+        out = "\n".join(out.split("\n")[2:])
         return out
 
     def __str__(self):
@@ -665,3 +696,28 @@ def remove_parameters(docstring, parameters):
     ds = Docstring(docstring)
     ds.remove_parameters(parameters)
     return str(ds)
+
+
+def indent(text, prefix, predicate=None):
+    """
+    Non-protected indent
+
+    Parameters
+    ----------
+    text : {None, str}
+        If None, function always returns ""
+    prefix : str
+        Prefix to add to the start of each line
+    predicate : callable, optional
+        If provided, 'prefix' will only be added to the lines
+        where 'predicate(line)' is True. If 'predicate' is not provided,
+        it will default to adding 'prefix' to all non-empty lines that do not
+        consist solely of whitespace characters.
+
+    Returns
+    -------
+
+    """
+    if text is None:
+        return ""
+    return textwrap.indent(text, prefix, predicate=predicate)
