@@ -2,6 +2,7 @@
 Author: Terence L van Zyl
 Modified: Kevin Sheppard
 """
+from statsmodels.compat.pandas import MONTH_END
 from statsmodels.compat.pytest import pytest_warns
 
 import os
@@ -108,7 +109,7 @@ def ses():
     for i in range(1, 1200):
         y[i] = y[i - 1] + e[i] - 0.2 * e[i - 1]
     y = y[200:]
-    index = pd.date_range("2000-1-1", periods=y.shape[0], freq="M")
+    index = pd.date_range("2000-1-1", periods=y.shape[0], freq=MONTH_END)
     return pd.Series(y, index=index, name="y")
 
 
@@ -489,10 +490,10 @@ class TestHoltWinters:
         fit5 = mod5.fit()
         # We accept the below values as we getting a better SSE than text book
         assert_almost_equal(fit1.params["smoothing_level"], 1.00, 2)
-        assert_almost_equal(fit1.params["smoothing_trend"], np.NaN, 2)
-        assert_almost_equal(fit1.params["damping_trend"], np.NaN, 2)
+        assert_almost_equal(fit1.params["smoothing_trend"], np.nan, 2)
+        assert_almost_equal(fit1.params["damping_trend"], np.nan, 2)
         assert_almost_equal(fit1.params["initial_level"], 263.96, 1)
-        assert_almost_equal(fit1.params["initial_trend"], np.NaN, 2)
+        assert_almost_equal(fit1.params["initial_trend"], np.nan, 2)
         assert_almost_equal(fit1.sse, 6761.35, 2)  # 6080.26
         assert isinstance(fit1.summary().as_text(), str)
 
@@ -546,7 +547,7 @@ class TestHoltWinters:
         alt_params = {k: v for k, v in params.items() if "level" not in k}
         with mod.fix_params(alt_params):
             alt_fit = mod.fit(optimized=True)
-        assert not np.allclose(alt_fit.trend[0], opt_fit.trend[0])
+        assert not np.allclose(alt_fit.trend.iloc[0], opt_fit.trend.iloc[0])
         # Summary output
         # print(res$mse)
         assert_allclose(fit.sse / mod.nobs, 195.4397924865488, atol=1e-3)
@@ -947,7 +948,7 @@ def test_equivalence_cython_python(trend, seasonal):
     p[:6] = alpha, beta, gamma, l0, b0, phi
     if seasonal:
         p[6:] = params["initial_seasons"]
-    xi = np.ones_like(p).astype(int)
+    xi = np.ones_like(p).astype(np.int64)
 
     p_copy = p.copy()
 
@@ -1758,7 +1759,7 @@ def test_to_restricted_equiv(params):
     bounds = np.array([[0.0, 1.0]] * 3)
     assert_allclose(
         to_restricted(params, sel, bounds),
-        _test_to_restricted(params, sel.astype(int), bounds),
+        _test_to_restricted(params, sel.astype(np.int64), bounds),
     )
 
 
@@ -1995,7 +1996,7 @@ def test_forecast_index_types(ses, index_typ):
     if index_typ == "period":
         index = pd.period_range("2000-1-1", periods=nobs + 36, freq="M")
     elif index_typ == "date_range":
-        index = pd.date_range("2000-1-1", periods=nobs + 36, freq="M")
+        index = pd.date_range("2000-1-1", periods=nobs + 36, freq=MONTH_END)
     elif index_typ == "range":
         index = pd.RangeIndex(nobs + 36)
         kwargs["seasonal_periods"] = 12
